@@ -31,6 +31,7 @@ class NumpyLoaderBase(object):
             Args:
             path:    local file system path to dataset. All the
                      Parquet files assume the same petastorm schema. 
+            fname:   signale parquet filename.
             url:     file or s3 URL to parquet dataset
             dataset: string, name of the dataset
             columns: categories to load. Availale categories include:
@@ -40,6 +41,7 @@ class NumpyLoaderBase(object):
     def __init__(self, **pars):
         self.pars = {
             'path' : "",
+            'fname' : "",
             'url' : "",
             'dataset' : "",
             'columns' : ['imdata', 'label']
@@ -70,6 +72,16 @@ class NumpyLoaderBase(object):
                 if not self.loader_meta:
                     _pf = pq.ParquetFile(parquets[0])
                     self.loader_meta = _pf.metadata
+        elif os.path.isfile(self.pars['fname']):
+            f, e = os.path.splitext(self.pars['fname'])
+            if not e=='.parquet':
+                raise Exception('File shall have parquet extension!')
+            self.loader = pq.read_table(
+                source=self.pars['fname']).to_pandas()
+            self.loader_size = self.loader.shape[0]
+            if not self.loader_meta:
+                self.loader_meta = pq.ParquetFile(
+                    self.pars['fname']).metadata
         elif self.pars['url'].startswith("file://") or \
             self.pars['url'].startswith("s3://"):
             pass
@@ -100,7 +112,41 @@ class NumpyLoaderBase(object):
         memfile = io.BytesIO(example.label)
         label = np.load(memfile)
         return (im, label)
-        
+    
+    def partition(self, partition=[0.80, 0.10, 0.10], out_path=""):
+        """Upload a file to an S3 bucket
+
+        Args:
+        partition: 3-element list of partition ratios
+        out_path: directory to save exported datasets
+
+        """
+        if not out_path:
+            raise Exception('Valid out_path has to be provided!')
+        if not os.path.isdir(out_path):
+            os.makedirs(out_path)
+        if not sum(partition)==1.0:
+            partition = [x/sum(partition) for x in partition]
+        train, eval, test = np.split(
+            self.loader.sample(frac=1),
+            [int(partition[0]*len(self.loader)),
+             int(sum(partition[:2])*len(self.loader))
+            ]
+        )
+        dlen = []
+        if len(train)>0:
+            dlen.append(len(train))
+            train.to_parquet(os.path.join(out_path, 'train.parquet'))
+        if len(eval)>0:
+            dlen.append(len(eval))
+            eval.to_parquet(os.path.join(out_path, 'eval.parquet'))
+        if len(test)>0:
+            dlen.append(len(test))
+            test.to_parquet(os.path.join(out_path, 'test.parquet'))
+        print("///: The dataset was partitioned into train/eval/test")
+        print("///: in ratios of {}".format(partition))
+        print("///: train/eval/test size: {}".format(dlen))
+            
 
 
 
